# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "Also available in": "Saatavilla myös",
    "Archive": "Arkisto",
    "Categories": "Kategoriat",
    "LANGUAGE": "Suomi",
    "More posts about": "Lisää postauksia aiheesta",
    "Newer posts": "Uudempia postauksia",
    "Next post": "Seuraava postaus",
    "Older posts": "Vanhempia postauksia",
    "Original site": "Alkuperäinen sivusto",
    "Posted": "Postattu",
    "Posts about %s": "Postauksia aiheesta %s",
    "Posts for year %s": "Postauksia vuodelta %s",
    "Posts for {month} {year}": "Postauksia ajalle {month} {year}",
    "Previous post": "Vanhempia postauksia",
    "Read in English": "Lue suomeksi",
    "Read more": "Lue lisää",
    "Source": "Lähde",
    "Tags and Categories": "Tagit ja kategoriat",
    "Tags": "Tagit",
    "old posts page %d": "vanhojen postauksien sivu %d",
}
